@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine;
 # ABSTRACT: composable units of assertion
-$Test::Routine::VERSION = '0.020';
+$Test::Routine::VERSION = '0.023';
 #pod =head1 SYNOPSIS
 #pod
 #pod   # mytest.t
@@ -312,7 +312,7 @@ Test::Routine - composable units of assertion
 
 =head1 VERSION
 
-version 0.020
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -521,6 +521,30 @@ When you run it:
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Alex White Dagfinn Ilmari Mannsåker Jesse Luehrs Yanick Champoux
+
+=over 4
+
+=item *
+
+Alex White <VVu@geekfarm.org>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Ricardo Signes.
