@@ -1,6 +1,6 @@
 package Test::Routine::Common;
 # ABSTRACT: a role composed by all Test::Routine roles
-$Test::Routine::Common::VERSION = '0.020';
+$Test::Routine::Common::VERSION = '0.023';
 use Moose::Role;
 
 #pod =head1 OVERVIEW
@@ -10,7 +10,7 @@ use Moose::Role;
 #pod
 #pod =cut
 
-use Test::More ();
+use Test2::API 1.302045 ();
 
 use namespace::autoclean;
 
@@ -18,7 +18,7 @@ sub run_test {
   my ($self, $test) = @_;
 
   my $name = $test->name;
-  Test::More::subtest($test->description, sub { $self->$name });
+  Test2::API::run_subtest($test->description, sub { $self->$name });
 }
 
 1;
@@ -35,7 +35,7 @@ Test::Routine::Common - a role composed by all Test::Routine roles
 
 =head1 VERSION
 
-version 0.020
+version 0.023
 
 =head1 OVERVIEW
 
